@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymond_client.c 7636 2015-04-19 00:36:43Z jccleaver $";
+static char rcsid[] = "$Id: xymond_client.c 7704 2015-10-19 20:26:58Z jccleaver $";
 
 #include <stdio.h>
 #include <string.h>
@@ -914,6 +914,7 @@ void unix_memory_report(char *hostname, char *clientclass, enum ostype_t os,
 {
 	long memphyspct = 0, memswappct = 0, memactpct = 0;
 	int physyellow, physred, swapyellow, swapred, actyellow, actred;
+	int invaliddata = 0;
 
 	int memorycolor = COL_GREEN, physcolor = COL_GREEN, swapcolor = COL_GREEN, actcolor = COL_GREEN;
 	char *memorysummary = "OK";
@@ -937,26 +938,32 @@ void unix_memory_report(char *hostname, char *clientclass, enum ostype_t os,
 		if (memswappct > swapyellow) swapcolor = COL_YELLOW;
 		if (memswappct > swapred)    swapcolor = COL_RED;
 	}
+	else invaliddata = 1;
 
 	if (memactused != -1) memactpct = (memphystotal > 0) ? ((100 * memactused) / memphystotal) : 0;
 	if (memactpct <= 100) {
 		if (memactpct  > actyellow)  actcolor  = COL_YELLOW;
 		if (memactpct  > actred)     actcolor  = COL_RED;
 	}
+	else invaliddata = 1;
 
-	if ((physcolor == COL_YELLOW) || (swapcolor == COL_YELLOW) || (actcolor == COL_YELLOW)) {
-		memorycolor = COL_YELLOW;
-		memorysummary = "low";
-	}
 	if ((physcolor == COL_RED) || (swapcolor == COL_RED) || (actcolor == COL_RED)) {
 		memorycolor = COL_RED;
 		memorysummary = "CRITICAL";
 	}
+	else if ((physcolor == COL_YELLOW) || (swapcolor == COL_YELLOW) || (actcolor == COL_YELLOW)) {
+		memorycolor = COL_YELLOW;
+		memorysummary = "low";
+	}
 
 	if ((memphystotal == 0) && (memorycolor == COL_GREEN)) {
 		memorycolor = COL_YELLOW;
 		memorysummary = "detection FAILED";
 	}
+	else if (invaliddata) {
+		if (memorycolor != COL_RED) memorycolor = COL_YELLOW;
+		memorysummary = "invalid data when parsing";
+	}
 
 	init_status(memorycolor);
 	sprintf(msgline, "status %s.memory %s %s - Memory %s\n",
@@ -978,7 +985,7 @@ void unix_memory_report(char *hostname, char *clientclass, enum ostype_t os,
 				colorname(actcolor), "Actual", memactused, memphystotal, memactpct);
 		else
 			sprintf(msgline, "&%s %-12s%11ldM%11ldM%11ld%% - invalid data\n", 
-				colorname(COL_CLEAR), "Actual", memactused, memphystotal, 0L);
+				colorname(COL_YELLOW), "Actual", memactused, memphystotal, 0L);
 			
 		addtostatus(msgline);
 	}
@@ -989,7 +996,7 @@ void unix_memory_report(char *hostname, char *clientclass, enum ostype_t os,
 				colorname(swapcolor), "Swap", memswapused, memswaptotal, memswappct);
 		else
 			sprintf(msgline, "&%s %-12s%11ldM%11ldM%11ld%% - invalid data\n", 
-				colorname(COL_CLEAR), "Swap", memswapused, memswaptotal, 0L);
+				colorname(COL_YELLOW), "Swap", memswapused, memswaptotal, 0L);
 
 		addtostatus(msgline);
 	}
@@ -1398,7 +1405,7 @@ void file_report(char *hostname, char *clientclass, enum ostype_t os,
 			}
 
 			if (!anyrules) {
-				/* Dont clutter the display with logfiles unless they have rules */
+				/* Don't clutter the display with logfiles unless they have rules */
 				continue;
 			}
 		}
